MethodChannelFlutterLitertLm class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
countTokens(String engineId, String text)
→ Future<int>
-
Get the number of tokens in the given text.
override
-
createConversation(String engineId, Map<String, dynamic>? config)
→ Future<String>
-
Create a conversation on the given engine.
Returns a conversation ID.
override
-
createEngine(Map<String, dynamic> config)
→ Future<String>
-
Create and initialize an engine with the given config.
Returns an engine ID.
override
-
disposeConversation(String conversationId)
→ Future<void>
-
Dispose a conversation and release its resources.
override
-
disposeEngine(String engineId)
→ Future<void>
-
Dispose an engine and release its resources.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(String conversationId, List<Map<String, dynamic>> contents, )
→ Future<Map<String, dynamic>>
-
Send a message synchronously and return the full response.
override
-
sendMessageStream(String conversationId, List<Map<String, dynamic>> contents, )
→ Stream<Map<String, dynamic>>
-
Send a message and stream back partial responses as they're generated.
override
-
toString()
→ String
-
A string representation of this object.
inherited